--- log.lisp.orig	2011-03-14 10:05:55.000000000 -1000
+++ log.lisp	2011-03-14 10:45:00.000000000 -1000
@@ -32,27 +32,33 @@
 (defmacro with-open-file-or-console ((stream-var pathname lock) &body body)
   "Helper macro to write log entries.  STREAM-VAR is a symbol that
 will be bound to the logging stream during the execution of BODY.
-PATHNAME is the pathname designator of the log file or NIL if logging
-should be done to *ERROR-OUTPUT*.  LOCK refers to the lock that should
-be held during the logging operation.  If PATHNAME is not NIL, a flexi
-stream with UTF-8 encoding will be created and bound to STREAM-VAR.
-If an error occurs while writing to the log file, that error will be
-logged to *ERROR-OUTPUT*."
+PATHNAME is the pathname designator of the log file or T if logging
+should be done to *ERROR-OUTPUT*, or NIL for no logging. LOCK refers to
+the lock that should be held during the logging operation.  If
+PATHNAME is not NIL, a flexi stream with UTF-8 encoding will be
+created and bound to STREAM-VAR.  If an error occurs while writing to
+the log file, that error will be logged to *ERROR-OUTPUT*."
   (with-unique-names (binary-stream)
     (with-rebinding (pathname)
       (let ((body body))
-        `(if ,pathname
-             (with-lock-held (,lock)
-               (with-open-file (,binary-stream ,pathname
-                                               :direction :output
-                                               :element-type 'octet
-                                               :if-does-not-exist :create
-                                               :if-exists :append
-                                               #+:openmcl #+:openmcl
-                                               :sharing :lock)
-                 (let ((,stream-var (make-flexi-stream ,binary-stream :external-format +utf-8+)))
-                   ,@body)))
-             (let ((,stream-var *error-output*))
-               (prog1 (progn ,@body)
-                 (finish-output *error-output*))))))))
+        `(cond ((not ,pathname) ;; if pathname is NIL, do not log
+		NIL) 
+	       ;;
+	       ((eq ,pathname t) ;; if pathname is T, log to *ERROR-OUTPUT*
+		(let ((,stream-var *error-output*))
+		 (prog1 (progn ,@body)
+		   (finish-output *error-output*)))) 
+	       ;;
+	       (T   ;; otherwise, log to a file
+		(with-lock-held (,lock)
+		  (with-open-file (,binary-stream ,pathname
+						  :direction :output
+						  :element-type 'octet
+						  :if-does-not-exist :create
+						  :if-exists :append
+						  #+:openmcl #+:openmcl
+						  :sharing :lock)
+		    (let ((,stream-var (make-flexi-stream 
+					,binary-stream :external-format +utf-8+)))
+		      ,@body)))))))))
   
